@@ -50,6 +50,7 @@ private Q_SLOTS:
     void testQueryByMimeType();
     void testThreads();
     void testTraderQueryMustRebuildSycoca();
+    void testSetPreferredService();
     void cleanupTestCase();
 
 private:
@@ -108,7 +109,7 @@ void KApplicationTraderTest::initTestCase()
 
 void KApplicationTraderTest::cleanupTestCase()
 {
-    for (const QString &file : qAsConst(m_createdDesktopFiles)) {
+    for (const QString &file : std::as_const(m_createdDesktopFiles)) {
         QFile::remove(file);
     }
 }
@@ -246,7 +247,7 @@ void KApplicationTraderTest::testTraderConstraints_data()
 
     // Test another property, parsed as a double
     FF testVersion = [](const KService::Ptr &serv) {
-        double d = serv->property(QStringLiteral("X-KDE-Version"), QVariant::Double).toDouble();
+        double d = serv->property(QStringLiteral("X-KDE-Version"), QMetaType::Double).toDouble();
         return d > 5.559 && d < 5.561;
     };
     QTest::newRow("float_parsing") << testVersion << ExpectedResult::FakeApplicationAndOthers;
@@ -323,8 +324,13 @@ void KApplicationTraderTest::testThreads()
     QThreadPool::globalInstance()->setMaxThreadCount(10);
     QFutureSynchronizer<void> sync;
     // Can't use data-driven tests here, QTestLib isn't threadsafe.
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    sync.addFuture(QtConcurrent::run(&KApplicationTraderTest::testQueryByMimeType, this));
+    sync.addFuture(QtConcurrent::run(&KApplicationTraderTest::testQueryByMimeType, this));
+#else
     sync.addFuture(QtConcurrent::run(this, &KApplicationTraderTest::testQueryByMimeType));
     sync.addFuture(QtConcurrent::run(this, &KApplicationTraderTest::testQueryByMimeType));
+#endif
     sync.waitForFinished();
 }
 
@@ -339,4 +345,14 @@ void KApplicationTraderTest::testTraderQueryMustRebuildSycoca()
     QCOMPARE(offers.count(), 1);
 }
 
+void KApplicationTraderTest::testSetPreferredService()
+{
+    const KService::Ptr oldPref = KApplicationTrader::preferredService(QLatin1String("text/plain"));
+    const KService::Ptr newPref = KService::serviceByDesktopPath(m_fakeApplication);
+    KApplicationTrader::setPreferredService(QLatin1String("text/plain"), newPref);
+    QCOMPARE(KApplicationTrader::preferredService(QLatin1String("text/plain"))->entryPath(), m_fakeApplication);
+    KApplicationTrader::setPreferredService(QLatin1String("text/plain"), oldPref);
+    QCOMPARE(KApplicationTrader::preferredService(QLatin1String("text/plain"))->storageId(), oldPref->storageId());
+}
+
 #include "kapplicationtradertest.moc"
