@@ -61,7 +61,7 @@ QTEST_MAIN(KSycocaDictTest)
 void KSycocaDictTest::runKBuildSycoca()
 {
 #if KSERVICE_BUILD_DEPRECATED_SINCE(5, 80)
-    QSignalSpy spy(KSycoca::self(), QOverload<const QStringList &>::of(&KSycoca::databaseChanged));
+    QSignalSpy spy(KSycoca::self(), qOverload<const QStringList &>(&KSycoca::databaseChanged));
 #else
     QSignalSpy spy(KSycoca::self(), &KSycoca::databaseChanged);
 #endif
@@ -93,19 +93,18 @@ void KSycocaDictTest::testStandardDict()
     // clang-format on
 
     // Skip servicetypes that are not installed
-    QMutableListIterator<QString> it(serviceTypes);
-    while (it.hasNext()) {
-        if (!KServiceType::serviceType(it.next())) {
-            it.remove();
-        }
-    }
+    auto it = std::remove_if(serviceTypes.begin(), serviceTypes.end(), [](const QString &s) {
+        return !KServiceType::serviceType(s);
+    });
+    serviceTypes.erase(it, serviceTypes.end());
+
     qDebug() << serviceTypes;
 
     QBENCHMARK {
         QByteArray buffer;
         {
             KSycocaDict dict;
-            for (const QString &str : qAsConst(serviceTypes)) {
+            for (const QString &str : std::as_const(serviceTypes)) {
                 add(dict, str, str);
             }
             dict.remove(QStringLiteral("DictTestPluginType")); // just to test remove
@@ -120,7 +119,7 @@ void KSycocaDictTest::testStandardDict()
         int offset = loadingDict.find_string(QStringLiteral("DictTestPluginType"));
         QVERIFY(offset > 0);
         QCOMPARE(offset, KServiceType::serviceType(QStringLiteral("DictTestPluginType"))->offset());
-        for (const QString &str : qAsConst(serviceTypes)) {
+        for (const QString &str : std::as_const(serviceTypes)) {
             int offset = loadingDict.find_string(str);
             QVERIFY(offset > 0);
             QCOMPARE(offset, KServiceType::serviceType(str)->offset());
