@@ -11,6 +11,7 @@
 #include "klauncher_iface.h"
 #include <KDEInitInterface>
 #endif
+#include "kservice.h"
 #include <KLocalizedString>
 
 #include <QCoreApplication>
@@ -165,6 +166,7 @@ int KToolInvocation::startServiceByName(const QString &_name,
 }
 #endif
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 82)
 int KToolInvocation::startServiceByDesktopPath(const QString &_name,
                                                const QString &URL,
                                                QString *error,
@@ -183,7 +185,9 @@ int KToolInvocation::startServiceByDesktopPath(const QString &_name,
     }
     return self()->startServiceInternal("start_service_by_desktop_path", _name, URLs, error, serviceName, pid, startup_id, noWait);
 }
+#endif
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 82)
 int KToolInvocation::startServiceByDesktopPath(const QString &_name,
                                                const QStringList &URLs,
                                                QString *error,
@@ -198,7 +202,9 @@ int KToolInvocation::startServiceByDesktopPath(const QString &_name,
 
     return self()->startServiceInternal("start_service_by_desktop_path", _name, URLs, error, serviceName, pid, startup_id, noWait);
 }
+#endif
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 82)
 int KToolInvocation::startServiceByDesktopName(const QString &_name,
                                                const QString &URL,
                                                QString *error,
@@ -217,7 +223,9 @@ int KToolInvocation::startServiceByDesktopName(const QString &_name,
     }
     return self()->startServiceInternal("start_service_by_desktop_name", _name, URLs, error, serviceName, pid, startup_id, noWait);
 }
+#endif
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 82)
 int KToolInvocation::startServiceByDesktopName(const QString &_name,
                                                const QStringList &URLs,
                                                QString *error,
@@ -232,7 +240,9 @@ int KToolInvocation::startServiceByDesktopName(const QString &_name,
 
     return self()->startServiceInternal("start_service_by_desktop_name", _name, URLs, error, serviceName, pid, startup_id, noWait);
 }
+#endif
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 83)
 int KToolInvocation::kdeinitExec(const QString &name, const QStringList &args, QString *error, int *pid, const QByteArray &startup_id)
 {
     if (!isMainThreadActive(error)) {
@@ -241,6 +251,7 @@ int KToolInvocation::kdeinitExec(const QString &name, const QStringList &args, Q
 
     return self()->startServiceInternal("kdeinit_exec", name, args, error, nullptr, pid, startup_id, false);
 }
+#endif
 
 int KToolInvocation::kdeinitExecWait(const QString &name, const QStringList &args, QString *error, int *pid, const QByteArray &startup_id)
 {
@@ -308,3 +319,5 @@ void KToolInvocation::ensureKdeinitRunning()
     KDEInitInterface::ensureKdeinitRunning();
 #endif
 }
+
+#include "moc_ktoolinvocation.cpp"
