@@ -7,6 +7,10 @@
     SPDX-License-Identifier: LGPL-2.0-only
 */
 
+#include <QtGlobal>
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+
 #include "kplugintrader.h"
 #include "ktraderparsetree_p.h"
 
@@ -14,6 +18,8 @@
 #include <KPluginMetaData>
 #include <QVector>
 
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 82)
+
 using namespace KTraderParse;
 
 KPluginTrader *KPluginTrader::self()
@@ -75,3 +81,5 @@ KPluginInfo::List KPluginTrader::query(const QString &subDirectory, const QStrin
     applyConstraints(lst, constraint);
     return lst;
 }
+
+#endif
